%--------------------------------------------------------------------------
% File     : GRP132-1.SIZE : TPTP v2.0.0. Released v1.2.0.
% Domain   : Group Theory (Quasigroups)
% Problem  : (3,1,2) conjugate orthogonality, no idempotence
% Version  : [Slaney, 1993] axioms. 
% English  : Generate the multiplication table for the specified quasi-
%            group with SIZE elements.

% Refs     : Fujita M., Slaney J., Bennett F. (1993), Automatic Generation
%            of Some Results in Finite Algebra, Bajcsy R. (Ed), 
%            Proceedings of the 13th International Joint Conference on
%            Artificial Intelligence (Chambery, France, 1993), Morgan
%            Kaufman, San Mateo, USA, 52-57.
%          : Slaney J. (1993), Email to Geoff Sutcliffe.
%          : Slaney J., Fujita M., Stickel M. (1995), Automated Reasoning
%            and Exhaustive Search: Quasigroup Existence Problems,
%            Computers and Mathematics with Applications 29(2), 115-132.
% Source   : [Slaney, 1993]
% Names    : QG2-ni [Slaney, 1993]

% Status   : STATUS
% Rating   : ? v2.0.0
% Syntax   : 

% Comments : Slaney's [1993] axiomatization has been modified for this.
%          : Substitution axioms are not needed, as any positive equality
%            literals should resolve on negative ones directly.
%          : As in GRP130-1, either one of qg2_1 or qg2_2 may be used, as 
%            each implies the other in this scenario, with the help of 
%            cancellation. The dependence cannot be proved, so both have 
%            been left in here.
%--------------------------------------------------------------------------
%----Include basic quasigroup code
:-tptp2X_include('Generators/GRP123-1.g').
%--------------------------------------------------------------------------
%----The status of this problem (including some open!)
'GRP132-1_status'(Size,unsatisfiable):-
    tptp2X_member(Size,[2,6]),
    !.

'GRP132-1_status'(_,satisfiable):-
    !.
%--------------------------------------------------------------------------
'GRP132-1'(Size,Clauses,Status):-
    integer(Size),
    'GRP123-1_qg_element_clauses'(Size,ElementClauses),
    'GRP123-1_standard_qg_clauses'(Size,product,StandardClauses,no),
    tptp2X_append(ElementClauses,StandardClauses,AxiomClauses),
    tptp2X_append(AxiomClauses,[
input_clause(qg2_1,conjecture,
    [--product('X1','Y1','Z1'),
     --product('X2','Y2','Z1'),
     --product('Z2','X1','Y1'),
     --product('Z2','X2','Y2'),
     ++equalish('X1','X2')]),
input_clause(qg2_2,conjecture,
    [--product('X1','Y1','Z1'),
     --product('X2','Y2','Z1'),
     --product('Z2','X1','Y1'),
     --product('Z2','X2','Y2'),
     ++equalish('Y1','Y2')])],Clauses),
    'GRP132-1_status'(Size,Status).
%--------------------------------------------------------------------------
%----Provide information about the GRP132-1 generator
'GRP132-1_file_information'(generator,sizes(X,(X>=1)),sota(2)).
%--------------------------------------------------------------------------
