%--------------------------------------------------------------------------
% File     : COL071-1 : TPTP v2.0.0. Released v1.2.0.
% Domain   : Combinatory Logic
% Problem  : Strong fixed point for N and Q
% Version  : [Wos & McCune, 1988] (equality) axioms.
% English  : The strong fixed point property holds for the set 
%            P consisting of the combinators N and Q, where ((Nx)y)z 
%            = ((xz)y)z, ((Qx)y)z = y(xz).

% Refs     : Wos L., McCune W.W (1988), Challenge Problems Focusing 
%            on Equality and Combinatory Logic: Evaluating Automated 
%            Theorem-Proving Programs, Proceedings of the 9th 
%            International Conference on Automated Deduction (Argonne, IL, 
%            1988), (Lecture Notes in Computer Science, 310), 714-729.
%          : Wos L. (1993), The Kernel Strategy and its use for the Study 
%            of Combinatory Logic, Journal of Automated Reasoning 10(3), 
%            287-343.
%          : Zhang J. (1995), Email to Geoff Sutcliffe.
% Source   : [Wos, 1993]
% Names    : Question 14 [Wos, 1993]

% Status   : unknown
% Rating   : 1.00 v2.0.0
% Syntax   : Number of clauses    :    9 (   0 non-Horn;   4 unit;   4 RR)
%            Number of literals   :   15 (  15 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    1 (   0 propositional; 2-2 arity)
%            Number of functors   :    4 (   2 constant; 0-2 arity)
%            Number of variables  :   21 (   0 singleton)
%            Maximal term depth   :    4 (   1 average)

% Comments : Jian Zhang [Zhang, 1995] provided a 4 element model of these 
%            clauses.
%          : Thought to be satisfiable.
%--------------------------------------------------------------------------
%----Include the axioms of equality 
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(n_definition,axiom,
    [++equal(apply(apply(apply(n,X),Y),Z),apply(apply(apply(X,Z),Y),Z))]).

input_clause(q_definition,axiom,
    [++equal(apply(apply(apply(q,X),Y),Z),apply(Y,apply(X,Z)))]).

input_clause(apply_substitution1,axiom,
    [--equal(A,B),
     ++equal(apply(A,C),apply(B,C))]).

input_clause(apply_substitution2,axiom,
    [--equal(D,E),
     ++equal(apply(F,D),apply(F,E))]).

input_clause(f_substitution1,axiom,
    [--equal(G,H),
     ++equal(f(G),f(H))]).

input_clause(prove_fixed_point,conjecture,
    [--equal(apply(Y,f(Y)),apply(f(Y),apply(Y,f(Y))))]).
%--------------------------------------------------------------------------
