%--------------------------------------------------------------------------
% File     : GRP031-2 : TPTP v2.0.0. Released v1.0.0.
% Domain   : Group Theory (Semigroups)
% Problem  : In semigroups, left inverse and id => right inverse exists
% Version  : [McCharen, et al., 1976] axioms : Reduced > Incomplete.
% English  : If there are right inverses and right identity, then every 
%            element has a left inverse.

% Refs     : Lawrence J.D., Starkey J.D. (1974), Experimental tests 
%            of resolution based theorem-proving strategies, Technical 
%            Report, Computer Science Department, Washington State 
%            University, Pullman, Washington.
%          : Wilson G.A. and Minker J. (1976), Resolution, Refinements, 
%            and Search Strategies: A Comparative Study, IEEE Transactions 
%            on Computers C-25(8), 782-801.
% Source   : [SPRFN]
% Names    : ls23 [Lawrence & Starkey, 1974]
%          : ls23 [Wilson & Minker, 1976]

% Status   : unsatisfiable
% Rating   : 0.00 v2.0.0
% Syntax   : Number of clauses    :    7 (   0 non-Horn;   4 unit;   4 RR)
%            Number of literals   :   15 (   0 equality)
%            Maximal clause size  :    4 (   2 average)
%            Number of predicates :    2 (   0 propositional; 2-3 arity)
%            Number of functors   :    4 (   2 constant; 0-2 arity)
%            Number of variables  :   21 (   1 singleton)
%            Maximal term depth   :    2 (   1 average)

% Comments : This can also be viewed as a group theory problem, showing 
%            that the left inverse axiom is dependant on the rest of the 
%            axiom set; i.e., if there is a right inverse then there 
%            is a left inverse.
%--------------------------------------------------------------------------
%----Don't include semi-group axioms because most equality is missing
%include('Axioms/GRP002-0.ax').
%--------------------------------------------------------------------------
%----This axiom is called closure or totality in some axiomatisations 
input_clause(total_function1,axiom,
    [++product(X,Y,multiply(X,Y))]).

%----This axiom is called well_definedness in some axiomatisations 
input_clause(total_function2,axiom,
    [--product(X,Y,Z),
     --product(X,Y,W),
     ++equalish(Z,W)]).

input_clause(associativity1,axiom,
    [--product(X,Y,U),
     --product(Y,Z,V),
     --product(U,Z,W),
     ++product(X,V,W)]).

input_clause(associativity2,axiom,
    [--product(X,Y,U),
     --product(Y,Z,V),
     --product(X,V,W),
     ++product(U,Z,W)]).

input_clause(right_inverse,hypothesis,
    [++product(A,inverse(A),identity)]).

input_clause(right_identity,hypothesis,
    [++product(A,identity,A)]).

input_clause(prove_a_has_a_left_inverse,conjecture,
    [--product(A,a,identity)]).
%--------------------------------------------------------------------------
