%--------------------------------------------------------------------------
% File     : MGT019+2 : TPTP v2.0.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Growth rate of EPs exceeds that of FMs in stable environments
% Version  : [Peli, et al., 1993] axioms.
% English  : The growth rate of efficent producers exceeds the growth rate 
%          : of first movers past a certain time in stable environments.

% Refs     : Peli G., Bruggeman J., Masuch M. (1993), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, CCSOM Report
%            93-100, Department of Statistics and Methodology, University
%            of Amsterdam, Amsterdam, The Netherlands.
%          : Peli G., Bruggeman J., Masuch M. (1994), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, Moore D.P. (Ed),
%            Best Papers Proceedings of the 54th Annual Academy of
%            Management Convention (Dallas, USA, 1994), 218-222.
% Source   : [Peli, et al., 1993]
% Names    : LEMMA 1 [Peli, et al., 1993]
%          : L1 [Peli, et al., 1994]

% Status   : satisfiable
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :   26 (   1 unit)
%            Number of atoms       :   75 (  31 equality)
%            Maximal formula depth :    8 (   4 average)
%            Number of connectives :   50 (   1 ~  ;   1  |;  21  &)
%                                         (   0 <=>;  27 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    7 (   0 propositional; 1-4 arity)
%            Number of functors    :    5 (   2 constant; 0-2 arity)
%            Number of variables   :   77 (   0 singleton;  75 !;   2 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : There is no MGT019+1 as Kamps did not send it to me.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(disbanding_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(disbanding_rate(A,C),disbanding_rate(B,C)) )   )).

input_formula(disbanding_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(disbanding_rate(C,A),disbanding_rate(C,B)) )   )).

input_formula(founding_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(founding_rate(A,C),founding_rate(B,C)) )   )).

input_formula(founding_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(founding_rate(C,A),founding_rate(C,B)) )   )).

input_formula(growth_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(A,C),growth_rate(B,C)) )   )).

input_formula(growth_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(C,A),growth_rate(C,B)) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(stable_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & stable(A) )
     => stable(B) )   )).

input_formula(subpopulations_substitution_1,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(A,C,D,E) )
     => subpopulations(B,C,D,E) )   )).

input_formula(subpopulations_substitution_2,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,A,D,E) )
     => subpopulations(C,B,D,E) )   )).

input_formula(subpopulations_substitution_3,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,A,E) )
     => subpopulations(C,D,B,E) )   )).

input_formula(subpopulations_substitution_4,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,E,A) )
     => subpopulations(C,D,E,B) )   )).

%----Problem axioms
%----L2. The disbanding rate of first movers exceeds the disbanding
%----rate of efficient producers.
input_formula(l2,axiom,(
    ~ ( ! [E,T] : 
          ( ( environment(E)
            & subpopulations(first_movers,efficient_producers,E,T) )
         => greater(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T)) ) )   )).

%----If EP have lower disbanding rate and not lower founding rate than 
%----FM, then EP have higher growth rate.
input_formula(mp_EP_lower_disbanding_rate,axiom,(
    ! [T] : 
      ( ( greater(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))
        & greater_or_equal(founding_rate(efficient_producers,T),
founding_rate(first_movers,T)) )
     => greater(growth_rate(efficient_producers,T),
growth_rate(first_movers,T)) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
     => ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----A8.  The founding rate of first movers does not exceed the founding
%----rate of efficient producers past a certain point in a stable 
%----environment.
input_formula(a8,hypothesis,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( in_environment(E,To)
          & ! [T] : 
              ( ( subpopulations(first_movers,efficient_producers,E,T)
                & greater_or_equal(T,To) )
             => greater_or_equal(founding_rate(efficient_producers,T),
founding_rate(first_movers,T)) ) ) )   )).

%----GOAL: L1. The growth rate of efficient producers exceeds the growth 
%----rate of first movers past a certain time in stable environments.
input_formula(prove_l1,conjecture,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( in_environment(E,To)
          & ! [T] : 
              ( ( subpopulations(first_movers,efficient_producers,E,T)
                & greater_or_equal(T,To) )
             => greater(growth_rate(efficient_producers,T),
growth_rate(first_movers,T)) ) ) )   )).
%--------------------------------------------------------------------------
