%--------------------------------------------------------------------------
% File     : MGT022+2 : TPTP v2.0.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Decreasing resource availability affects FMS more than EPs
% Version  : [Peli, et al., 1993] axioms.
% English  : Decreasing resource availability affects the disbanding rate 
%          : of first movers more than the disbanding rate of efficient 
%          : producers.

% Refs     : Peli G., Bruggeman J., Masuch M. (1993), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, CCSOM Report
%            93-100, Department of Statistics and Methodology, University
%            of Amsterdam, Amsterdam, The Netherlands.
%          : Peli G., Bruggeman J., Masuch M. (1994), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, Moore D.P. (Ed),
%            Best Papers Proceedings of the 54th Annual Academy of
%            Management Convention (Dallas, USA, 1994), 218-222.
% Source   : [Peli, et al., 1993]
% Names    : LEMMA 4 [Peli, et al., 1993]
%          : L4 [Peli, et al., 1994]

% Status   : theorem
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :    4 (   1 unit)
%            Number of atoms       :   16 (   0 equality)
%            Maximal formula depth :    6 (   4 average)
%            Number of connectives :   14 (   2 ~  ;   0  |;   5  &)
%                                         (   0 <=>;   7 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    6 (   0 propositional; 1-4 arity)
%            Number of functors    :    6 (   2 constant; 0-2 arity)
%            Number of variables   :    7 (   0 singleton;   7 !;   0 ?)
%            Maximal term depth    :    3 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----MP. If something is constant, then it does not decreases.
input_formula(mp_constant_not_decrease,axiom,(
    ! [X] : 
      ( constant(X)
     => ~ decreases(X) )   )).

%----A6. Less resilient subpopulations are more affected by decreasing
%----resource availability.
input_formula(a6,hypothesis,(
    ! [E,S1,S2,T] : 
      ( ( environment(E)
        & subpopulations(S1,S2,E,T)
        & greater(resilience(S2),resilience(S1)) )
     => ( ( decreases(resources(E,T))
         => increases(difference(disbanding_rate(S1,T),
disbanding_rate(S2,T))) )
        & ( constant(resources(E,T))
         => constant(difference(disbanding_rate(S1,T),
disbanding_rate(S2,T))) ) ) )   )).

%----A2. Efficient producers are more resilient than first movers.
input_formula(a2,hypothesis,(
    greater(resilience(efficient_producers),resilience(first_movers))   )).

%----GOAL: L4. A decreasing resource availability affects the disbanding 
%----rate of first movers more than the disbanding rate of efficient 
%----producers.
input_formula(prove_l4,conjecture,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => ( ( decreases(resources(E,T))
         => increases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))) )
        & ( constant(resources(E,T))
         => ~ decreases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))) ) ) )   )).
%--------------------------------------------------------------------------
