%--------------------------------------------------------------------------
% File     : MGT027+1 : TPTP v2.0.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : The FM set contracts in stable environments
% Version  : [Peli, et al., 1994] axioms : Reduced & Augmented > Complete.
% English  : The first mover set begins to contract past a certain time 
%          : in stable environments. 

% Refs     : Peli G., Bruggeman J., Masuch M. (1993), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, CCSOM Report
%            93-100, Department of Statistics and Methodology, University
%            of Amsterdam, Amsterdam, The Netherlands.
%          : Peli G., Bruggeman J., Masuch M. (1994), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, Moore D.P. (Ed),
%            Best Papers Proceedings of the 54th Annual Academy of
%            Management Convention (Dallas, USA, 1994), 218-222.
%          : Kamps J. (1995), Email to Geoff Sutcliffe.
% Source   : [Kamps, 1995]
% Names    : 

% Status   : unknown
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :   32 (   1 unit)
%            Number of atoms       :  100 (  33 equality)
%            Maximal formula depth :    9 (   4 average)
%            Number of connectives :   68 (   0 ~  ;   1  |;  34  &)
%                                         (   1 <=>;  32 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    8 (   0 propositional; 1-4 arity)
%            Number of functors    :    6 (   3 constant; 0-2 arity)
%            Number of variables   :   93 (   0 singleton;  91 !;   2 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(appear_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(A,C),appear(B,C)) )   )).

input_formula(appear_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(C,A),appear(C,B)) )   )).

input_formula(cardinality_at_time_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(A,C),cardinality_at_time(B,C)) )   )).

input_formula(cardinality_at_time_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(C,A),cardinality_at_time(C,B)) )   )).

input_formula(growth_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(A,C),growth_rate(B,C)) )   )).

input_formula(growth_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(C,A),growth_rate(C,B)) )   )).

input_formula(contracts_from_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & contracts_from(A,C) )
     => contracts_from(B,C) )   )).

input_formula(contracts_from_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & contracts_from(C,A) )
     => contracts_from(C,B) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(stable_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & stable(A) )
     => stable(B) )   )).

input_formula(subpopulations_substitution_1,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(A,C,D,E) )
     => subpopulations(B,C,D,E) )   )).

input_formula(subpopulations_substitution_2,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,A,D,E) )
     => subpopulations(C,B,D,E) )   )).

input_formula(subpopulations_substitution_3,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,A,E) )
     => subpopulations(C,D,B,E) )   )).

input_formula(subpopulations_substitution_4,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,E,A) )
     => subpopulations(C,D,E,B) )   )).

%----Problem axioms
%----MP on "contracts from"
input_formula(mp_contracts_from,axiom,(
    ! [E,To] : 
      ( ( environment(E)
        & stable(E)
        & in_environment(E,To)
        & ! [T] : 
            ( ( greater(cardinality_at_time(first_movers,T),zero)
              & greater_or_equal(T,To) )
           => greater(zero,growth_rate(first_movers,T)) ) )
     => contracts_from(To,first_movers) )   )).

%----MP. If FM and EP have members in the environment, then they are
%----non-empty subpopulations.
input_formula(mp_non_empty_fm_and_ep,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater(cardinality_at_time(first_movers,T),zero)
        & greater(cardinality_at_time(efficient_producers,T),zero) )
     => subpopulations(first_movers,efficient_producers,E,T) )   )).

%----MP. Stable environments are long.
input_formula(mp_long_stable_environments,axiom,(
    ! [E,T1,T2] : 
      ( ( environment(E)
        & stable(E)
        & in_environment(E,T1)
        & greater(T2,T1) )
     => in_environment(E,T2) )   )).

%----MP. Efficient producers appear in stable environments.
input_formula(mp_EP_in_stable_environments,axiom,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => in_environment(E,appear(efficient_producers,E)) )   )).

%----MP. inequality
input_formula(mp_greater_transitivity,axiom,(
    ! [X,Y,Z] : 
      ( ( greater(X,Y)
        & greater(Y,Z) )
     => greater(X,Z) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
    <=> ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----T6. Once appeared in an environment, efficient producers do not
%----disappear.
input_formula(t6,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater_or_equal(T,appear(efficient_producers,E)) )
     => greater(cardinality_at_time(efficient_producers,T),zero) )   )).

%----L10. First movers have negative growth rate past a certain point of
%----time (also after the appearence of efficient producers) in stable
%----environments.
input_formula(l10,hypothesis,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( greater(To,appear(efficient_producers,E))
          & ! [T] : 
              ( ( subpopulations(first_movers,efficient_producers,E,T)
                & greater_or_equal(T,To) )
             => greater(zero,growth_rate(first_movers,T)) ) ) )   )).

%----GOAL: L9. The first mover set begins to contract past a certain time 
%----in stable environments.
input_formula(prove_l9,conjecture,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( greater(To,appear(efficient_producers,E))
          & contracts_from(To,first_movers) ) )   )).
%--------------------------------------------------------------------------
