%--------------------------------------------------------------------------
% File     : MGT029+1 : TPTP v2.0.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : EPs have positive and FMs have negative growth rates
% Version  : [Peli, et al., 1994] axioms : Reduced & Augmented > Complete.
% English  : Efficient producers have positive, while first movers have
%          : negative growth rate past a certain point of time in stable
%          : environments. 

% Refs     : Peli G., Bruggeman J., Masuch M. (1993), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, CCSOM Report
%            93-100, Department of Statistics and Methodology, University
%            of Amsterdam, Amsterdam, The Netherlands.
%          : Peli G., Bruggeman J., Masuch M. (1994), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, Moore D.P. (Ed),
%            Best Papers Proceedings of the 54th Annual Academy of
%            Management Convention (Dallas, USA, 1994), 218-222.
%          : Kamps J. (1995), Email to Geoff Sutcliffe.
% Source   : [Kamps, 1995]
% Names    : 

% Status   : unknown
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :   25 (   1 unit)
%            Number of atoms       :   85 (  28 equality)
%            Maximal formula depth :    8 (   4 average)
%            Number of connectives :   60 (   0 ~  ;   5  |;  29  &)
%                                         (   1 <=>;  25 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    7 (   0 propositional; 1-4 arity)
%            Number of functors    :    5 (   3 constant; 0-2 arity)
%            Number of variables   :   74 (   0 singleton;  71 !;   3 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(equilibrium_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(equilibrium(A),equilibrium(B)) )   )).

input_formula(growth_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(A,C),growth_rate(B,C)) )   )).

input_formula(growth_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(C,A),growth_rate(C,B)) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(stable_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & stable(A) )
     => stable(B) )   )).

input_formula(subpopulations_substitution_1,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(A,C,D,E) )
     => subpopulations(B,C,D,E) )   )).

input_formula(subpopulations_substitution_2,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,A,D,E) )
     => subpopulations(C,B,D,E) )   )).

input_formula(subpopulations_substitution_3,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,A,E) )
     => subpopulations(C,D,B,E) )   )).

input_formula(subpopulations_substitution_4,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,E,A) )
     => subpopulations(C,D,E,B) )   )).

%----Problem axioms
%----MP. inequality
input_formula(mp_greater_transitivity,axiom,(
    ! [X,Y,Z] : 
      ( ( greater(X,Y)
        & greater(Y,Z) )
     => greater(X,Z) )   )).

%----MP. times in environment
input_formula(mp_times_in_environment,axiom,(
    ! [E,T1,T2] : 
      ( ( in_environment(E,T1)
        & in_environment(E,T2) )
     => ( greater(T2,T1)
        | equal(T2,T1)
        | greater(T1,T2) ) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
    <=> ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----L6. If a subpopulation has positive growth rate, then the
%----other subpopulation must have negative growth rate in equilibrium.
input_formula(l6,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T)
        & greater_or_equal(T,equilibrium(E)) )
     => ( ( equal(growth_rate(first_movers,T),zero)
          & equal(growth_rate(efficient_producers,T),zero) )
        | ( greater(growth_rate(first_movers,T),zero)
          & greater(zero,growth_rate(efficient_producers,T)) )
        | ( greater(growth_rate(efficient_producers,T),zero)
          & greater(zero,growth_rate(first_movers,T)) ) ) )   )).

%----L1. The growth rate of efficient producers exceeds the growth rate of
%----first movers past a certain time in stable environments.
input_formula(l1,hypothesis,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( in_environment(E,To)
          & ! [T] : 
              ( ( subpopulations(first_movers,efficient_producers,E,T)
                & greater_or_equal(T,To) )
             => greater(growth_rate(efficient_producers,T),
growth_rate(first_movers,T)) ) ) )   )).

%----A4. The state of equilibrium is reached in stable environments.
input_formula(a4,hypothesis,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [T] : 
          ( in_environment(E,T)
          & greater_or_equal(T,equilibrium(E)) ) )   )).

%----GOAL: L11. Efficient producers have positive, while first movers have
%----negative growth rate past a certain point of time in stable
%----environments.
input_formula(prove_l11,conjecture,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( in_environment(E,To)
          & ! [T] : 
              ( ( subpopulations(first_movers,efficient_producers,E,T)
                & greater_or_equal(T,To) )
             => ( greater(growth_rate(efficient_producers,T),zero)
                & greater(zero,growth_rate(first_movers,T)) ) ) ) )   )).
%--------------------------------------------------------------------------
