%--------------------------------------------------------------------------
% File     : MGT032+2 : TPTP v2.0.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Selection favours EPs above FMs
% Version  : [Peli, et al., 1993] axioms.
% English  : In stable environments, selection favors efficient producers 
%          : above first movers past a certain point in time. 

% Refs     : Peli G., Bruggeman J., Masuch M. (1993), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, CCSOM Report
%            93-100, Department of Statistics and Methodology, University
%            of Amsterdam, Amsterdam, The Netherlands.
%          : Peli G., Bruggeman J., Masuch M. (1994), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, Moore D.P. (Ed),
%            Best Papers Proceedings of the 54th Annual Academy of
%            Management Convention (Dallas, USA, 1994), 218-222.
%          : Kamps J. (1995), Email to Geoff Sutcliffe.
% Source   : [Peli, et al., 1993]
% Names    : THEOREM 1 [Peli, et al., 1993]
%          : T1 [Peli, et al., 1994]

% Status   : theorem
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :    3 (   0 unit)
%            Number of atoms       :   16 (   0 equality)
%            Maximal formula depth :    8 (   7 average)
%            Number of connectives :   13 (   0 ~  ;   0  |;   8  &)
%                                         (   0 <=>;   5 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    7 (   0 propositional; 1-4 arity)
%            Number of functors    :    3 (   2 constant; 0-2 arity)
%            Number of variables   :   10 (   0 singleton;   8 !;   2 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----MP1. Selection favors subpopulations with higher growth rates.
input_formula(mp1_high_growth_rates,axiom,(
    ! [E,S1,S2,T] : 
      ( ( environment(E)
        & subpopulations(S1,S2,E,T)
        & greater(growth_rate(S2,T),growth_rate(S1,T)) )
     => selection_favors(S2,S1,T) )   )).

%----L1. The growth rate of efficient producers exceeds the growth rate of
%----first movers past a certain time in stable environments.
input_formula(l1,hypothesis,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( in_environment(E,To)
          & ! [T] : 
              ( ( subpopulations(first_movers,efficient_producers,E,T)
                & greater_or_equal(T,To) )
             => greater(growth_rate(efficient_producers,T),
growth_rate(first_movers,T)) ) ) )   )).

%----GOAL: T1. Selection favors efficient producers above first movers
%----past a certain time in stable environments.
input_formula(prove_t1,conjecture,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( in_environment(E,To)
          & ! [T] : 
              ( ( subpopulations(first_movers,efficient_producers,E,T)
                & greater_or_equal(T,To) )
             => selection_favors(efficient_producers,first_movers,
T) ) ) )   )).
%--------------------------------------------------------------------------
