%--------------------------------------------------------------------------
% File     : MGT039+2 : TPTP v2.0.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Selection favours EPs above Fms if change is slow
% Version  : [Peli, et al., 1993] axioms.
% English  : Selection favors efficient producers above first movers if
%          : environmental change is slow. 

% Refs     : Peli G., Bruggeman J., Masuch M. (1993), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, CCSOM Report
%            93-100, Department of Statistics and Methodology, University
%            of Amsterdam, Amsterdam, The Netherlands.
%          : Peli G., Bruggeman J., Masuch M. (1994), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, Moore D.P. (Ed),
%            Best Papers Proceedings of the 54th Annual Academy of
%            Management Convention (Dallas, USA, 1994), 218-222.
%          : Kamps J. (1995), Email to Geoff Sutcliffe.
% Source   : [Peli, et al., 1993]
% Names    : Theorem 8 [Peli, et al., 1994]

% Status   : unknown
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :   51 (   3 unit)
%            Number of atoms       :  155 (  47 equality)
%            Maximal formula depth :    9 (   4 average)
%            Number of connectives :  106 (   2 ~  ;   1  |;  52  &)
%                                         (   1 <=>;  50 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :   11 (   0 propositional; 1-4 arity)
%            Number of functors    :    9 (   3 constant; 0-2 arity)
%            Number of variables   :  138 (   0 singleton; 137 !;   1 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(appear_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(A,C),appear(B,C)) )   )).

input_formula(appear_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(C,A),appear(C,B)) )   )).

input_formula(cardinality_at_time_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(A,C),cardinality_at_time(B,C)) )   )).

input_formula(cardinality_at_time_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(C,A),cardinality_at_time(C,B)) )   )).

input_formula(critical_point_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(critical_point(A),critical_point(B)) )   )).

input_formula(end_time_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(end_time(A),end_time(B)) )   )).

input_formula(growth_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(A,C),growth_rate(B,C)) )   )).

input_formula(growth_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(C,A),growth_rate(C,B)) )   )).

input_formula(start_time_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(start_time(A),start_time(B)) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(observational_period_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & observational_period(A) )
     => observational_period(B) )   )).

input_formula(propagation_strategy_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & propagation_strategy(A) )
     => propagation_strategy(B) )   )).

input_formula(selection_favors_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(A,C,D) )
     => selection_favors(B,C,D) )   )).

input_formula(selection_favors_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(C,A,D) )
     => selection_favors(C,B,D) )   )).

input_formula(selection_favors_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(C,D,A) )
     => selection_favors(C,D,B) )   )).

input_formula(slow_change_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & slow_change(A) )
     => slow_change(B) )   )).

input_formula(subpopulation_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & subpopulation(A,C,D) )
     => subpopulation(B,C,D) )   )).

input_formula(subpopulation_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & subpopulation(C,A,D) )
     => subpopulation(C,B,D) )   )).

input_formula(subpopulation_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & subpopulation(C,D,A) )
     => subpopulation(C,D,B) )   )).

input_formula(subpopulations_substitution_1,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(A,C,D,E) )
     => subpopulations(B,C,D,E) )   )).

input_formula(subpopulations_substitution_2,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,A,D,E) )
     => subpopulations(C,B,D,E) )   )).

input_formula(subpopulations_substitution_3,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,A,E) )
     => subpopulations(C,D,B,E) )   )).

input_formula(subpopulations_substitution_4,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,E,A) )
     => subpopulations(C,D,E,B) )   )).

%----Problem axioms
%----MP1. Selection favors subpopulations with higher growth rates.
input_formula(mp1_high_growth_rates,axiom,(
    ! [E,S1,S2,T] : 
      ( ( environment(E)
        & subpopulations(S1,S2,E,T)
        & greater(growth_rate(S2,T),growth_rate(S1,T)) )
     => selection_favors(S2,S1,T) )   )).

%----MP2. Selection favors organizational sets with members to set without
%----members.
input_formula(mp2_favour_members,axiom,(
    ! [E,S1,S2,T] : 
      ( ( environment(E)
        & subpopulation(S1,E,T)
        & subpopulation(S2,E,T)
        & greater(cardinality_at_time(S1,T),zero)
        & equal(cardinality_at_time(S2,T),zero) )
     => selection_favors(S1,S2,T) )   )).

%----MP3. If selection favors organizations of a certain propagation
%----strategy, s1, above an other, s2, at the endpoints of all 
%----environments in the observational period, then it favors s1 above 
%----s2 during the whole observational period.  
%----Instantiation: EP = s1 ; FM = s2
input_formula(mp3_favoured_trategy,axiom,(
    ! [P] : 
      ( ( observational_period(P)
        & propagation_strategy(first_movers)
        & propagation_strategy(efficient_producers)
        & ! [E] : 
            ( ( environment(E)
              & in_environment(P,E) )
           => selection_favors(efficient_producers,first_movers,
end_time(E)) ) )
     => selection_favors(efficient_producers,first_movers,P) )   )).

%----MP4. If environmental change is slow during an observational 
%----period, then all the environments in the observational period contain a
%----critical point.
input_formula(mp4_critical_point,axiom,(
    ! [P] : 
      ( ( observational_period(P)
        & slow_change(P) )
     => ! [E] : 
          ( ( environment(E)
            & in_environment(P,E) )
         => ? [T] : 
              ( in_environment(E,T)
              & greater(T,critical_point(E)) ) ) )   )).

%----MP. First movers and efficient producers are organizational sets of a
%----certain propagation strategy.
input_formula(mp_organizational_sets1,axiom,(
    propagation_strategy(first_movers)   )).

input_formula(mp_organizational_sets2,axiom,(
    propagation_strategy(efficient_producers)   )).

%----MP. If a time point occurs between the beginning and the end of the
%----environment, then it belongs to the environment.
input_formula(mp_time_in_environment,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & greater_or_equal(T,start_time(E))
        & greater_or_equal(end_time(E),T) )
     => in_environment(E,T) )   )).

%----MP. If a time point belongs to the environment, then the end-point of
%----the environment cannot precede it.
input_formula(mp_environment_end_point,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T) )
     => greater_or_equal(end_time(E),T) )   )).

%----MP.  If the number of both first movers and efficient producers is
%----positive in an environment, then the population in this environment 
%----contains a first mover and an efficient producer subpopulation.
input_formula(mp_contains_FM_and_EP,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater(cardinality_at_time(first_movers,T),zero)
        & greater(cardinality_at_time(efficient_producers,T),zero) )
     => subpopulations(first_movers,efficient_producers,E,T) )   )).

%----MP. The number of first movers cannot be negative.
input_formula(mp_first_movers_exist,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T) )
     => greater_or_equal(cardinality_at_time(first_movers,T),zero) )   )).

%----MP. First movers and efficient producers are subpopulations.
input_formula(mp_subpopulations,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T) )
     => ( subpopulation(first_movers,E,T)
        & subpopulation(efficient_producers,E,T) ) )   )).

%----MP. The critical point cannot precede the appearence of efficient
%----producers.
input_formula(mp_critical_point_after_EP,axiom,(
    ! [E] : 
      ( environment(E)
     => greater_or_equal(critical_point(E),
appear(efficient_producers,E)) )   )).

%----MP. The critical point of an environment cannot precede the
%----environment's opening time.
input_formula(mp_time_of_critical_point,axiom,(
    ! [E] : 
      ( environment(E)
     => greater_or_equal(critical_point(E),start_time(E)) )   )).

%----MP. inequality
input_formula(mp_greater_transitivity,axiom,(
    ! [X,Y,Z] : 
      ( ( greater(X,Y)
        & greater(Y,Z) )
     => greater(X,Z) )   )).

%----MP. on beginning and ending times
input_formula(mp_beginning_and_ending,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & greater(T,start_time(E))
        & ~ greater(T,end_time(E)) )
     => greater_or_equal(end_time(E),T) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
    <=> ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----D1(<=). If a time-point is the critical point of the environment,
%----then it is the earliest time past which the growth rate of efficient
%----producers permanently exceeds growth rate of first movers.
input_formula(d1,hypothesis,(
    ! [E,Tc] : 
      ( ( environment(E)
        & equal(Tc,critical_point(E)) )
     => ( ~ greater(growth_rate(efficient_producers,Tc),
growth_rate(first_movers,Tc))
        & ! [T] : 
            ( ( subpopulations(first_movers,efficient_producers,E,T)
              & greater(T,Tc) )
           => greater(growth_rate(efficient_producers,T),
growth_rate(first_movers,T)) ) ) )   )).

%----T6. Once appeared in an environment, efficient producers do not
%----disappear.
input_formula(t6,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater_or_equal(T,appear(efficient_producers,E)) )
     => greater(cardinality_at_time(efficient_producers,T),zero) )   )).

%----GOAL: T8. Selection favors efficient producers above first movers if
%----environmental change is slow.
input_formula(prove_t8,conjecture,(
    ! [P] : 
      ( ( observational_period(P)
        & slow_change(P) )
     => selection_favors(efficient_producers,first_movers,P) )   )).
%--------------------------------------------------------------------------
