%--------------------------------------------------------------------------
% File     : MGT041+2 : TPTP v2.0.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : There are non-FM and non-EP organisations
% Version  : [Peli, et al., 1993] axioms.
% English  : There are non-first mover and non-efficient producers
%          : organisations. 

% Refs     : Peli G., Bruggeman J., Masuch M. (1993), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, CCSOM Report
%            93-100, Department of Statistics and Methodology, University
%            of Amsterdam, Amsterdam, The Netherlands.
%          : Peli G., Bruggeman J., Masuch M. (1994), The Logic of
%            Propagation Strategies: Axiomatizing a Fragment of
%            Organizational Ecology in First Order Logic, Moore D.P. (Ed),
%            Best Papers Proceedings of the 54th Annual Academy of
%            Management Convention (Dallas, USA, 1994), 218-222.
%          : Kamps J. (1995), Email to Geoff Sutcliffe.
% Source   : [Peli, et al., 1993]
% Names    : Theorem 10 [Peli, et al., 1995]

% Status   : theorem
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :    5 (   0 unit)
%            Number of atoms       :   17 (   0 equality)
%            Maximal formula depth :    6 (   5 average)
%            Number of connectives :   16 (   4 ~  ;   0  |;  10  &)
%                                         (   0 <=>;   2 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    6 (   0 propositional; 1-3 arity)
%            Number of functors    :    2 (   2 constant; 0-0 arity)
%            Number of variables   :   10 (   1 singleton;   6 !;   4 ?)
%            Maximal term depth    :    1 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----MP. The number of routines cannot be low and high at the same time.
input_formula(mp_not_high_and_low,axiom,(
    ! [X,T] : 
      ~ ( number_of_routines(X,T,low)
        & number_of_routines(X,T,high) )   )).

%----A14. Efficient producer organizations have elaborated routines at 
%----their founding.
input_formula(a14,hypothesis,(
    ! [X,T] : 
      ( ( organisation_at_time(X,T)
        & efficient_producer(X)
        & founding_time(X,T) )
     => has_elaborated_routines(X,T) )   )).

%----A15. First mover organizations have only a few routines at their
%----founding.
input_formula(a15,hypothesis,(
    ! [X,T] : 
      ( ( organisation_at_time(X,T)
        & first_mover(X)
        & founding_time(X,T) )
     => number_of_routines(X,T,low) )   )).

%----A16. Some organizations come to birth with several, but poorly
%----elaborated routines are not elaborated.
input_formula(a16,hypothesis,(
    ? [X,T] : 
      ( organisation_at_time(X,T)
      & founding_time(X,T)
      & number_of_routines(X,T,high)
      & ~ has_elaborated_routines(X,T) )   )).

%----GOAL: T10. There are are non-first movers and non-efficient producer
%----organizations.
input_formula(prove_t10,conjecture,(
    ? [X,T] : 
      ( organisation_at_time(X,T)
      & ~ first_mover(X)
      & ~ efficient_producer(X) )   )).
%--------------------------------------------------------------------------
