%--------------------------------------------------------------------------
% File     : RNG007-5 : TPTP v2.0.0. Released v1.0.0.
% Domain   : Ring Theory
% Problem  : In Boolean rings, X is its own inverse
% Version  : [McCharen, et al., 1976] axioms : Augmented.
%            Theorem formulation : Equality.
% English  : Given a ring in which for all x, x * x = x, prove that for 
%            all x, x + x = additive_identity.

% Refs     : McCharen J.D., Overbeek R.A., Wos L.A. (1976), Problems and 
%            Experiments for and with Automated Theorem Proving Programs, 
%            IEEE Transactions on Computers C-25(8), 773-782.
%          : Peterson G.E., Stickel M.E. (1981), Complete Sets of
%            Reductions for Some Equational Theories, Journal of the ACM
%            28(2), 233-264.
% Source   : [ANL]
% Names    : lemma.ver1.in [ANL]

% Status   : unknown
% Rating   : 0.80 v2.0.0
% Syntax   : Number of clauses    :   39 (   0 non-Horn;  15 unit;  22 RR)
%            Number of literals   :   92 (  25 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :    3 (   0 propositional; 2-3 arity)
%            Number of functors   :    5 (   2 constant; 0-2 arity)
%            Number of variables  :  123 (   2 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : Extra lemmas based on [Peterson & Stickel,1981] equality 
%            axioms.
%--------------------------------------------------------------------------
%----Include Reflexivity, symmetry and transitivity, of equality 
include('Axioms/EQU001-0.ax').
%----Include ring theory axioms 
include('Axioms/RNG001-0.ax').
%----Include ring theory equality axioms 
include('Axioms/RNG001-0.eq').
%--------------------------------------------------------------------------
%----The next six clauses are the extra lemmas.
%----Inverse of identity is identity 
input_clause(additive_inverse_identity,axiom,
    [++sum(additive_inverse(additive_identity),additive_identity,
additive_identity)]).

%----Inverse of inverse of X is X 
input_clause(additive_inverse_additive_inverse,axiom,
    [++sum(additive_inverse(additive_inverse(X)),additive_identity,X)]).

%----Behavior of additive_identity and the multiplication operation 
input_clause(multiply_additive_id1,axiom,
    [++product(X,additive_identity,additive_identity)]).

input_clause(multiply_additive_id2,axiom,
    [++product(additive_identity,X,additive_identity)]).

%----Inverse of (x + y) is additive_inverse(x) + additive_inverse(y), 
input_clause(distribute_additive_inverse,axiom,
    [++sum(additive_inverse(X),additive_inverse(Y),
additive_inverse(add(X,Y)))]).

%----x * additive_inverse(y) = additive_inverse (x * y), 
input_clause(multiply_additive_inverse,axiom,
    [++product(X,additive_inverse(Y),additive_inverse(multiply(X,Y)))]).

%----Clauses for the theorem 
input_clause(x_squared_is_x,hypothesis,
    [++product(X,X,X)]).

input_clause(prove_a_plus_a_is_id,conjecture,
    [--equal(multiply(a,a),additive_identity)]).
%--------------------------------------------------------------------------
