%--------------------------------------------------------------------------
% File     : SET014-4 : TPTP v2.0.0. Bugfixed v1.2.1.
% Domain   : Set Theory
% Problem  : Union of subsets is a subset
% Version  : [Boyer, et al., 1986] axioms : Reduced > Incomplete.
% English  : If A and B are contained in C then the union of A and 
%            B is also.

% Refs     : Boyer R., Lusk E., McCune W., Overbeek R., Stickel M., Wos L. 
%            (1986), Set Theory in First-Order Logic: Clauses for Godel's 
%            Axioms,  Journal of Automated Reasoning 2(3), 287-327.
% Source   : [ANL]
% Names    : subset.ver2.in [ANL]

% Status   : unknown
% Rating   : 1.00 v2.0.0
% Syntax   : Number of clauses    :   35 (   4 non-Horn;   6 unit;  21 RR)
%            Number of literals   :   75 (  33 equality)
%            Maximal clause size  :    3 (   2 average)
%            Number of predicates :    4 (   0 propositional; 1-2 arity)
%            Number of functors   :   10 (   5 constant; 0-2 arity)
%            Number of variables  :   78 (   4 singleton)
%            Maximal term depth   :    4 (   1 average)

% Comments : 
% Bugfixes : v1.2.1 - Missing substitution axioms added.
%--------------------------------------------------------------------------
%----Include the axioms of equality 
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
%----Substitution axioms
input_clause(complement_substitution_1,axiom,
    [-- equal(A, B),
     ++ equal(complement(A), complement(B))]).

input_clause(f1_substitution_1,axiom,
    [-- equal(A, B),
     ++ equal(f1(A, C), f1(B, C))]).

input_clause(f1_substitution_2,axiom,
    [-- equal(A, B),
     ++ equal(f1(C, A), f1(C, B))]).

input_clause(f17_substitution_1,axiom,
    [-- equal(A, B),
     ++ equal(f17(A, C), f17(B, C))]).

input_clause(f17_substitution_2,axiom,
    [-- equal(A, B),
     ++ equal(f17(C, A), f17(C, B))]).

input_clause(intersection_substitution_1,axiom,
    [-- equal(A, B),
     ++ equal(intersection(A, C), intersection(B, C))]).

input_clause(intersection_substitution_2,axiom,
    [-- equal(A, B),
     ++ equal(intersection(C, A), intersection(C, B))]).

input_clause(union_substitution_1,axiom,
    [-- equal(A, B),
     ++ equal(union(A, C), union(B, C))]).

input_clause(union_substitution_2,axiom,
    [-- equal(A, B),
     ++ equal(union(C, A), union(C, B))]).

input_clause(little_set_substitution_1,axiom,
    [-- equal(A, B),
     -- little_set(A),
     ++ little_set(B)]).

input_clause(member_substitution_1,axiom,
    [-- equal(A, B),
     -- member(A, C),
     ++ member(B, C)]).

input_clause(member_substitution_2,axiom,
    [-- equal(A, B),
     -- member(C, A),
     ++ member(C, B)]).

input_clause(subset_substitution_1,axiom,
    [-- equal(A, B),
     -- subset(A, C),
     ++ subset(B, C)]).

input_clause(subset_substitution_2,axiom,
    [-- equal(A, B),
     -- subset(C, A),
     ++ subset(C, B)]).

%----Axiom A-2, elements of sets are little sets.
input_clause(a2,axiom,
    [--member(X,Y),
     ++little_set(X)]).

%----Axiom A-3, principle of extensionality 
input_clause(extensionality1,axiom,
    [++little_set(f1(X,Y)),
     ++equal(X,Y)]).

input_clause(extensionality2,axiom,
    [++member(f1(X,Y),X),
     ++member(f1(X,Y),Y),
     ++equal(X,Y)]).

input_clause(extensionality3,axiom,
    [--member(f1(X,Y),X),
     --member(f1(X,Y),Y),
     ++equal(X,Y)]).

%----Axiom B-2, intersection 
input_clause(intersection1,axiom,
    [--member(Z,intersection(X,Y)),
     ++member(Z,X)]).

input_clause(intersection2,axiom,
    [--member(Z,intersection(X,Y)),
     ++member(Z,Y)]).

input_clause(intersection3,axiom,
    [++member(Z,intersection(X,Y)),
     --member(Z,X),
     --member(Z,Y)]).

%----Axiom B-3, complement 
input_clause(complement1,axiom,
    [--member(Z,complement(X)),
     --member(Z,X)]).

input_clause(complement2,axiom,
    [++member(Z,complement(X)),
     --little_set(Z),
     ++member(Z,X)]).

%----Definition of union 
input_clause(union,axiom,
    [++equal(union(X,Y),complement(intersection(complement(X),
complement(Y))))]).

%----Definition of empty set 
input_clause(empty_set,axiom,
    [--member(Z,empty_set)]).

%----Definition of universal set 
input_clause(universal_set,axiom,
    [++member(Z,universal_set),
     --little_set(Z)]).

%----Definition of subset 
input_clause(subset1,axiom,
    [--subset(X,Y),
     --member(U,X),
     ++member(U,Y)]).

input_clause(subset2,axiom,
    [++subset(X,Y),
     ++member(f17(X,Y),X)]).

input_clause(subset3,axiom,
    [++subset(X,Y),
     --member(f17(X,Y),Y)]).

input_clause(a_subset_of_c,hypothesis,
    [++subset(as,cs)]).

input_clause(b_subset_of_c,hypothesis,
    [++subset(bs,cs)]).

input_clause(prove_a_union_b_subset_of_c,conjecture,
    [--subset(union(as,bs),cs)]).
%--------------------------------------------------------------------------
